"""Tags that are used ass CSS classes."""

ENTITY = 'entity'
SECTION = 'section'
INSTRUCTION = 'instruction'

SYNTAX_TEXT = 'syntax-text'
LITERAL_TEXT = 'syntax-text'

CONSOLE_TEXT = 'console'

TEXT_AS_HEADER = 'header-text'

ENUM_CONSTANT = 'enum-constant'

TOC_SECTION = 'toc'
